@@ -16,8 +16,10 @@ use Exception::Class (
     'Minions::Error::MethodDeclaration',
     'Minions::Error::RoleConflict',
 );
+use Minions::_Guts;
 
-our $VERSION = 0.000_003;
+our $VERSION = '0.000005';
+$VERSION = eval $VERSION;
 
 my $Class_count = 0;
 my %Bound_implementation_of;
@@ -53,7 +55,7 @@ sub minionize {
             $caller_pkg = (caller 1)[0];
         }
         $cls_stash = Package::Stash->new($caller_pkg);
-        $spec = { %$spec, %{ $cls_stash->get_symbol('%__Meta') || {} } };
+        $spec = { %$spec, %{ $cls_stash->get_symbol('%__meta__') || {} } };
         $spec->{name} = $caller_pkg;
     }
     $spec->{name} ||= "Minions::Class_${\ ++$Class_count }";
@@ -66,9 +68,10 @@ sub minionize {
         class_methods  => { type => HASHREF, optional => 1 },
         build_args     => { type => CODEREF, optional => 1 },
         name => { type => SCALAR, optional => 1 },
+        no_attribute_vars => { type => BOOLEAN, optional => 1 },
     });
     $cls_stash    ||= Package::Stash->new($spec->{name});
-    
+
     my $obj_stash;
 
     if ( ! ref $spec->{implementation} ) {
@@ -77,9 +80,9 @@ sub minionize {
           or confess "$spec->{name} cannot be its own implementation.";
         my $stash = _get_stash($pkg);
 
-        my $meta = $stash->get_symbol('%__Meta');
-        $spec->{implementation} = { 
-            package => $pkg, 
+        my $meta = $stash->get_symbol('%__meta__');
+        $spec->{implementation} = {
+            package => $pkg,
             methods => $stash->get_all_symbols('CODE'),
             has     => {
                 %{ $meta->{has} || { } },
@@ -95,15 +98,15 @@ sub minionize {
         }
     }
     $obj_stash = Package::Stash->new("$spec->{name}::__Minions");
-    
+
     _prep_interface($spec);
     _compose_roles($spec);
 
     my $private_stash = Package::Stash->new("$spec->{name}::__Private");
     $cls_stash->add_symbol('$__Obj_pkg', $obj_stash->name);
     $cls_stash->add_symbol('$__Private_pkg', $private_stash->name);
-    $cls_stash->add_symbol('%__Meta', $spec) if @_ > 0;
-    
+    $cls_stash->add_symbol('%__meta__', $spec) if @_ > 0;
+
     _make_util_class($spec);
     _add_class_methods($spec, $cls_stash);
     _add_methods($spec, $obj_stash, $private_stash);
@@ -114,7 +117,7 @@ sub minionize {
 
 sub utility_class {
     my ($class) = @_;
-    
+
     return $Util_class{ $class }
       or confess "Unknown class: $class";
 }
@@ -127,11 +130,11 @@ sub _prep_interface {
     {
 
         if (my $methods = $Interface_for{ $spec->{interface} }) {
-            $spec->{interface_name} = $spec->{interface};        
-            $spec->{interface} = $methods;        
+            $spec->{interface_name} = $spec->{interface};
+            $spec->{interface} = $methods;
         }
         else {
-            $count > 0 
+            $count > 0
               and confess "Invalid interface: $spec->{interface}";
             require_module($spec->{interface});
             $count++;
@@ -142,26 +145,26 @@ sub _prep_interface {
 
 sub _compose_roles {
     my ($spec, $roles, $from_role) = @_;
-    
+
     if ( ! $roles ) {
         $roles = $spec->{roles};
     }
-    
+
     $from_role ||= {};
-    
+
     for my $role ( @{ $roles } ) {
-        
+
         if ( $spec->{composed_role}{$role} ) {
             confess "Cannot compose role '$role' twice";
         }
         else {
             $spec->{composed_role}{$role}++;
         }
-        
+
         my ($meta, $method) = _load_role($role);
         $spec->{required}{$role} = $meta->{requires};
         _compose_roles($spec, $meta->{roles} || [], $from_role);
-        
+
         _add_role_items($spec, $from_role, $role, $meta->{has}, 'has');
         _add_role_methods($spec, $from_role, $role, $meta, $method);
     }
@@ -169,12 +172,12 @@ sub _compose_roles {
 
 sub _load_role {
     my ($role) = @_;
-    
+
     my $stash  = _get_stash($role);
-    my $meta   = $stash->get_symbol('%__Meta');
+    my $meta   = $stash->get_symbol('%__meta__');
     $meta->{role}
       or confess "$role is not a role";
-    
+
     my $method = $stash->get_all_symbols('CODE');
     return ($meta, $method);
 }
@@ -217,12 +220,12 @@ sub _get_stash {
 
     my $stash = Package::Stash->new($pkg); # allow for inlined pkg
 
-    if ( ! $stash->has_symbol('%__Meta') ) {
+    if ( ! $stash->has_symbol('%__meta__') ) {
         require_module($pkg);
         $stash = Package::Stash->new($pkg);
     }
-    if ( ! $stash->has_symbol('%__Meta') ) {
-        confess "Package $pkg has no %__Meta";
+    if ( ! $stash->has_symbol('%__meta__') ) {
+        confess "Package $pkg has no %__meta__";
     }
     return $stash;
 }
@@ -239,7 +242,7 @@ sub _add_role_items {
                 $spec->{implementation}{$type}{$name} = $item->{$name};
                 $from_role->{$name} = $role;
             }
-        }            
+        }
     }
 }
 
@@ -290,26 +293,28 @@ sub _raise_role_conflict {
 sub _get_object_maker {
 
     sub {
-        my $utility_class = shift;
+        my ($utility_class, $init) = @_;
 
         my $class = $utility_class->main_class;
-        
+
         my $stash = Package::Stash->new($class);
-        my %obj = ( 
-            '!' => ${ $stash->get_symbol('$__Private_pkg') },
-            $$  => {}, 
+
+        my $spec = $stash->get_symbol('%__meta__');
+        my $obfu_pkg = Minions::_Guts::obfu_name('', $spec);
+        my %obj = (
+            $obfu_pkg => ${ $stash->get_symbol('$__Private_pkg') },
         );
 
-        my $spec = $stash->get_symbol('%__Meta');
-        
         while ( my ($attr, $meta) = each %{ $spec->{implementation}{has} } ) {
-            $obj{$$}{$attr} = ref $meta->{default} eq 'CODE'
-              ? $meta->{default}->()
-              : $meta->{default};
+            my $obfu_name = Minions::_Guts::obfu_name($attr, $spec);
+            $obj{$obfu_name} = $init->{$attr}
+              ? $init->{$attr}
+              : (ref $meta->{default} eq 'CODE'
+                ? $meta->{default}->()
+                : $meta->{default});
         }
-        lock_keys(%{ $obj{$$} });
-        
-        bless \ %obj => ${ $stash->get_symbol('$__Obj_pkg') };            
+
+        bless \ %obj => ${ $stash->get_symbol('$__Obj_pkg') };
         lock_keys(%obj);
         return \ %obj;
     };
@@ -329,7 +334,7 @@ sub _add_class_methods {
 
 sub _make_util_class {
     my ($spec) = @_;
-    
+
     my $stash = Package::Stash->new("$spec->{name}::__Util");
     $Util_class{ $spec->{name} } = $stash->name;
 
@@ -338,21 +343,22 @@ sub _make_util_class {
     );
 
     $method{main_class} = sub { $spec->{name} };
-    
+
+    my $obfu_pkg = Minions::_Guts::obfu_name('', $spec);
     $method{build} = sub {
         my (undef, $obj, $arg) = @_;
-        if ( my $builder = $obj->{'!'}->can('BUILD') ) {
-            $builder->($obj->{'!'}, $obj, $arg);
+        if ( my $builder = $obj->{$obfu_pkg}->can('BUILD') ) {
+            $builder->($obj->{$obfu_pkg}, $obj, $arg);
         }
     };
-    
+
     $method{assert} = sub {
         my (undef, $slot, $val) = @_;
-        
+
         return unless exists $spec->{construct_with}{$slot};
-        
+
         my $meta = $spec->{construct_with}{$slot};
-        
+
         for my $desc ( keys %{ $meta->{assert} || {} } ) {
             my $code = $meta->{assert}{$desc};
             $code->($val)
@@ -361,7 +367,7 @@ sub _make_util_class {
     };
 
     my $class_var_stash = Package::Stash->new("$spec->{name}::__ClassVar");
-    
+
     $method{get_var} = sub {
         my ($class, $name) = @_;
         $class_var_stash->get_symbol($name);
@@ -380,7 +386,7 @@ sub _make_util_class {
 
 sub _add_default_constructor {
     my ($spec) = @_;
-    
+
     if ( ! exists $spec->{class_methods}{new} ) {
         $spec->{class_methods}{new} = sub {
             my $class = shift;
@@ -392,6 +398,9 @@ sub _add_default_constructor {
             elsif ( scalar @_ > 1 ) {
                 $arg = { @_ };
             }
+            if (my @unknown = grep { ! exists $spec->{construct_with}{$_} } keys %$arg) {
+                confess "Unknown args: [@unknown]";
+            }
 
             my $utility_class = utility_class($class);
             my $obj = $utility_class->new_object;
@@ -404,7 +413,7 @@ sub _add_default_constructor {
                     $utility_class->assert($name, $arg->{$name});
                 }
 
-                my ($attr, $dup) = grep { $spec->{implementation}{has}{$_}{init_arg} eq $name } 
+                my ($attr, $dup) = grep { $spec->{implementation}{has}{$_}{init_arg} eq $name }
                                         keys %{ $spec->{implementation}{has} };
                 if ( $dup ) {
                     confess "Cannot have same init_arg '$name' for attributes '$attr' and '$dup'";
@@ -412,18 +421,19 @@ sub _add_default_constructor {
                 if ( $attr ) {
                     _copy_assertions($spec, $name, $attr);
                     my $sub = $spec->{implementation}{has}{$attr}{map_init_arg};
-                    $obj->{$$}{$attr} = $sub ? $sub->($arg->{$name}) : $arg->{$name};
+                    my $obfu_name = Minions::_Guts::obfu_name($attr, $spec) ;
+                    $obj->{$obfu_name} = $sub ? $sub->($arg->{$name}) : $arg->{$name};
                 }
             }
-            
+
             $utility_class->build($obj, $arg);
             return $obj;
         };
-        
+
         my $build_args = $spec->{build_args} || $spec->{class_methods}{BUILDARGS};
         if ( $build_args ) {
             my $prev_new = $spec->{class_methods}{new};
-            
+
             $spec->{class_methods}{new} = sub {
                 my $class = shift;
                 $prev_new->($class, $build_args->($class, @_));
@@ -436,7 +446,7 @@ sub _copy_assertions {
     my ($spec, $name, $attr) = @_;
 
     my $meta = $spec->{construct_with}{$name};
-    
+
     for my $desc ( keys %{ $meta->{assert} || {} } ) {
         next if exists $spec->{implementation}{has}{$attr}{assert}{$desc};
 
@@ -451,11 +461,11 @@ sub _add_methods {
 
     $spec->{implementation}{semiprivate}{ASSERT} = sub {
         my (undef, $slot, $val) = @_;
-        
+
         return unless exists $spec->{implementation}{has}{$slot};
-        
+
         my $meta = $spec->{implementation}{has}{$slot};
-        
+
         for my $desc ( keys %{ $meta->{assert} || {} } ) {
             my $code = $meta->{assert}{$desc};
             $code->($val)
@@ -464,26 +474,39 @@ sub _add_methods {
     };
     $spec->{implementation}{methods}{DOES} = sub {
         my ($self, $r) = @_;
-        
+
         if ( ! $r ) {
-            return (( $spec->{interface_name} ? $spec->{interface_name} : () ), 
-                    $spec->{name}, sort keys %{ $spec->{composed_role} });
+            my @items = (( $spec->{interface_name} ? $spec->{interface_name} : () ),
+                          $spec->{name}, sort keys %{ $spec->{composed_role} });
+            return unless defined wantarray;
+            return wantarray ? @items : \@items;
         }
-        
+
         return    $r eq $spec->{interface_name}
-               || $spec->{name} eq $r 
-               || $spec->{composed_role}{$r} 
+               || $spec->{name} eq $r
+               || $spec->{composed_role}{$r}
                || $self->isa($r);
     };
-    
+    $spec->{implementation}{methods}{can} = sub {
+        my ($self, $f) = @_;
+
+        if ( ! $f ) {
+            my @items = sort @{ $spec->{interface} };
+            return unless defined wantarray;
+            return wantarray ? @items : \@items;
+        }
+        return UNIVERSAL::can($self, $f);
+    };
+
     while ( my ($name, $meta) = each %{ $spec->{implementation}{has} } ) {
 
         if ( !  $spec->{implementation}{methods}{$name}
-             && $meta->{reader} 
+             && $meta->{reader}
              && $in_interface->{$name} ) {
 
             my $name = $meta->{reader} == 1 ? $name : $meta->{reader};
-            $spec->{implementation}{methods}{$name} = sub { $_[0]->{$$}{$name} };
+            my $obfu_name = Minions::_Guts::obfu_name($name, $spec);
+            $spec->{implementation}{methods}{$name} = sub { $_[0]->{$obfu_name} };
         }
 
         if ( !  $spec->{implementation}{methods}{$name}
@@ -491,11 +514,12 @@ sub _add_methods {
              && $in_interface->{$name} ) {
 
             my $name = $meta->{writer} == 1 ? "change_$name" : $meta->{writer};
+            my $obfu_pkg = Minions::_Guts::obfu_name('', $spec);
             $spec->{implementation}{methods}{$name} = sub {
                 my ($self, $new_val) = @_;
 
-                $self->{'!'}->ASSERT($name, $new_val);
-                $self->{$$}{$name} = $new_val;
+                $self->{$obfu_pkg}->ASSERT($name, $new_val);
+                $self->{ Minions::_Guts::obfu_name($name, $spec) } = $new_val;
                 return $self;
             };
         }
@@ -503,6 +527,7 @@ sub _add_methods {
     }
 
     while ( my ($name, $sub) = each %{ $spec->{implementation}{methods} } ) {
+        next unless $in_interface->{$name};
         $stash->add_symbol("&$name", subname $stash->name."::$name" => $sub);
     }
     while ( my ($name, $sub) = each %{ $spec->{implementation}{semiprivate} } ) {
@@ -527,7 +552,8 @@ sub _add_delegates {
             (undef, $method) = _load_role($meta->{handles});
         }
         my $in_interface = _interface($spec);
-        
+        my $obfu_name = Minions::_Guts::obfu_name($name, $spec);
+
         foreach my $meth ( keys %{ $method } ) {
             if ( defined $spec->{implementation}{methods}{$meth} ) {
                 confess "Cannot override implemented method '$meth' with a delegated method";
@@ -536,8 +562,8 @@ sub _add_delegates {
                 my $target = $target_method->{$meth} || $meth;
                 $spec->{implementation}{methods}{$meth} =
                   $in_interface->{$meth}
-                    ? sub { shift->{$$}{$name}->$target(@_) }
-                    : sub { shift; shift->{$$}{$name}->$target(@_) };
+                    ? sub { shift->{$obfu_name}->$target(@_) }
+                    : sub { shift; shift->{$obfu_name}->$target(@_) };
             }
         }
     }
@@ -548,7 +574,7 @@ sub _interface {
 
     $type ||= 'interface';
     my %must_allow = (
-        interface   => [qw( DOES DESTROY )],
+        interface   => [qw( can DOES DESTROY )],
         semiprivate => [qw( BUILD )],
     );
     return { map { $_ => 1 } @{ $spec->{$type} }, @{ $must_allow{$type} } };
@@ -565,16 +591,8 @@ Minions - What is I<your> API?
 
 =head1 SYNOPSIS
 
-    package Example::Synopsis::Counter;
+    # Imagine a counter used like this:
 
-    use Minions
-        interface => [ qw( next ) ],
-        implementation => 'Example::Synopsis::Acme::Counter';
-
-    1;
-    
-    # In a script near by ...
-    
     use Test::Most tests => 5;
     use Example::Synopsis::Counter;
 
@@ -585,49 +603,99 @@ Minions - What is I<your> API?
     is $counter->next => 2;
 
     throws_ok { $counter->new } qr/Can't locate object method "new"/;
-    
-    throws_ok { Example::Synopsis::Counter->next } 
+
+    throws_ok { Example::Synopsis::Counter->next }
               qr/Can't locate object method "next" via package "Example::Synopsis::Counter"/;
 
-    
+
+    # The counter class:
+
+    package Example::Synopsis::Counter;
+
+    use Minions
+        interface => [ qw( next ) ],
+
+        implementation => 'Example::Synopsis::Acme::Counter';
+
+    1;
+
+
     # And the implementation for this class:
-    
+
     package Example::Synopsis::Acme::Counter;
-    
-    use strict;
-    
-    our %__Meta = (
-        has  => {
+
+    use Minions::Implementation
+        has => {
             count => { default => 0 },
-        }, 
-    );
-    
+        }
+    ;
+
     sub next {
         my ($self) = @_;
-    
-        $self->{$$}{count}++;
+
+        $self->{$__count}++;
     }
-    
-    1;    
-    
+
+    1;
+
 =head1 STATUS
 
 This is an early release available for testing and feedback and as such is subject to change.
 
 =head1 DESCRIPTION
 
-Minions is a class builder that makes it easy to create classes that are L<modular|http://en.wikipedia.org/wiki/Modular_programming>.
+Minions is a class builder that makes it easy to create classes that are L<modular|http://en.wikipedia.org/wiki/Modular_programming>, which means
+there is a clear separation between what end users need to know (the interface for using the class) and implementation details that users
+don't need to know about.
 
 Classes are built from a specification that declares the interface of the class (i.e. what commands minions of the classs respond to),
 as well as a package that provide the implementation of these commands.
 
 This separation of interface from implementation details is an important aspect of modular design, as it enables modules to be interchangeable (so long as they have the same interface).
 
-It is not a coincidence that the Object Oriented way as it was originally envisioned was mainly concerned with messaging,
+It is not a coincidence that the Object Oriented concept as originally envisioned was mainly concerned with messaging,
 where in the words of Alan Kay (who coined the term "Object Oriented Programming") objects are "like biological cells and/or individual computers on a network, only able to communicate with messages"
 and "OOP to me means only messaging, local retention and protection and hiding of state-process, and extreme late-binding of all things."
 (see L<The Deep Insights of Alan Kay|http://mythz.servicestack.net/blog/2013/02/27/the-deep-insights-of-alan-kay/>).
 
+=head1 RATIONALE
+
+Due to Perl's "assembly required" approach to OOP, there are many CPAN modules that exist to automate this assembly,
+perhaps the most popular being the L<Moose> family. Moo(se) is very effective at simplifying class building but this is typically achieved at the
+expense of Encapsulation (the hiding of implementation details from end users).
+
+Minions takes inspriation from Moose's declaratve approach to simplifying OO automation, but does not require or encourage encapsulation to be sacrificed.
+
+=head2 The Tale of Minions
+
+There once was a farmer who had a flock of sheep. His typical workday looked like:
+
+    $farmer->move_flock($pasture)
+    $farmer->monitor_flock()
+    $farmer->move_flock($home)
+
+    $farmer->other_important_work()
+
+In order to devote more time to C<other_important_work()>, the farmer decided to hire a minion, so the work was now split like this:
+
+    $shepherd_boy->move_flock($pasture)
+    $shepherd_boy->monitor_flock()
+    $shepherd_boy->move_flock($home)
+
+    $farmer->other_important_work()
+
+This did give the farmer more time for C<other_important_work()>, but unfornately C<$shepherd_boy> had a tendency to L<cry wolf|http://en.wikipedia.org/wiki/The_Boy_Who_Cried_Wolf> so the farmer had to replace him:
+
+    $sheep_dog->move_flock($pasture)
+    $sheep_dog->monitor_flock()
+    $sheep_dog->move_flock($home)
+
+    $farmer->other_important_work()
+
+C<$sheep_dog> was more reliable and demanded less pay than C<$shepherd_boy>, so this was a win for the farmer.
+
+Object Oriented design is essentially the act of minionization, i.e. deciding which minions ($objects) will do what work, and how to communicate with them (using an interface).
+
 =head1 USAGE
 
 =head2 Via Import
@@ -658,15 +726,15 @@ A class can be defined when importing Minions e.g.
 
 =head2 Minions->minionize([HASHREF])
 
-A class can also be defined by calling the C<minionize()> class method, with an optional hashref that 
+A class can also be defined by calling the C<minionize()> class method, with an optional hashref that
 specifies the class.
 
-If the hashref is not given, the specification is read from a package variable named C<%__Meta> in the package
+If the hashref is not given, the specification is read from a package variable named C<%__meta__> in the package
 from which C<minionize()> was called.
 
 The class defined in the SYNOPSIS could also be defined like this
 
-    use Test::Most tests => 4;
+    use Test::More tests => 2;
     use Minions ();
 
     my %Class = (
@@ -677,12 +745,12 @@ The class defined in the SYNOPSIS could also be defined like this
                 next => sub {
                     my ($self) = @_;
 
-                    $self->{$$}{count}++;
+                    $self->{-count}++;
                 }
             },
             has  => {
                 count => { default => 0 },
-            }, 
+            },
         },
     );
 
@@ -692,16 +760,13 @@ The class defined in the SYNOPSIS could also be defined like this
     is $counter->next => 0;
     is $counter->next => 1;
 
-    throws_ok { $counter->new } qr/Can't locate object method "new"/;
-    throws_ok { Counter->next } qr/Can't locate object method "next" via package "Counter"/;
-
 =head2 Examples
 
 Further examples of usage can be found in the following documents
 
 =over 4
 
-=item L<Minions::Construction>
+=item L<Minions::Manual::Construction>
 
 =back
 
@@ -736,114 +801,39 @@ The default constructor will call these predicates to validate the parameters pa
 
 The name of a package that defines the subroutines declared in the interface.
 
-The package may also contain other subroutines not declared in the interface that are for internal use in the package.
-These won't be callable using the C<$minion-E<gt>command(...)> syntax.
-
 Alternatively an implementation can be hashref as shown in the synopsis above.
 
-=head2 Configuring an implementation package
+L<Minions::Implementation> describes how implementations are configured.
 
-An implementation package can also be configured with a package variable C<%__Meta> with the following keys:
+=head2 Bindings
 
-=head3 has => HASHREF
+The implementation of a class can be quite easily changed from user code e.g. after
 
-This declares attributes of the implementation, mapping the name of an attribute to a hash with keys described in
-the following sub sections.
+    use Minions
+        bind => { 
+            'Foo' => 'Foo::Fake', 
+            'Bar' => 'Bar::Fake', 
+        };
+    use Foo;
+    use Bar;
 
-An attribute called "foo" can be accessed via it's object like this:
+Foo and bar will be bound to fake implementations (e.g. to aid with testing), instead of the implementations defined in
+their respective modules.
 
-    $self->{$$}{foo}
+=head2 Introspection
 
-Objects created by Minions are hashes,
-and are locked down to allow only keys declared in the "has" (implementation or role level)
-declarations. This is done to prevent accidents like mis-spelling an attribute name.
+Behavioural and Role introspection are possible using C<$object-E<gt>can> and C<$object-E<gt>DOES> which if called with no argument will return a list (or array ref depending on context) of methods or roles respectiively supported by the object.
 
-=head4 default => SCALAR | CODEREF
+See the section "Using multiple roles" from L<Minions::Role/EXAMPLES> for an example.
 
-The default value assigned to the attribute when the object is created. This can be an anonymous sub,
-which will be excecuted to build the the default value (this would be needed if the default value is a reference,
-to prevent all objects from sharing the same reference).
+Also note that for any class C<Foo> created using Minions, and for any object created with C<Foo>'s constructor, the following will always return a true value
 
-=head4 assert => HASHREF
-
-This is like the C<assert> declared in a class package, except that these assertions are not run at
-construction time. Rather they are invoked by calling the semiprivate ASSERT routine.
-
-=head4 handles => ARRAYREF | HASHREF | SCALAR
-
-This declares that methods can be forwarded from the object to this attribute in one of three ways
-described below. These forwarding methods are generated as public methods if they are declared in
-the interface, and as semiprivate routines otherwise.
-
-=head4 handles => ARRAYREF
-
-All methods in the given array will be forwarded.
-
-=head4 handles => HASHREF
-
-Method forwarding will be set up such that a method whose name is a key in the given hash will be
-forwarded to a method whose name is the corresponding value in the hash.
-
-=head4 handles => SCALAR
-
-The scalar is assumed to be a role, and methods provided directly (i.e. not including methods in sub-roles) by the role will be forwarded.
-
-=head4 reader => SCALAR
-
-This can be a string which if present will be the name of a generated reader method.
-
-This can also be the numerical value 1 in which case the generated reader method will have the same name as the key.
-
-Readers should only be created if they are logically part of the class API.
-
-=head3 semiprivate => ARRAYREF
-
-Any subroutines in this list will be semiprivate, i.e. they will not be callable as regular object methods but
-can be called using the syntax:
-
-    $obj->{'!'}->do_something(...)
-
-=head3 roles => ARRAYREF
-
-A reference to an array containing the names of one or more Role packages that define the subroutines declared in the interface.
-
-The packages may also contain other subroutines not declared in the interface that are for internal use in the package.
-These won't be callable using the C<$minion-E<gt>command(...)> syntax.
-
-=head2 Configuring a role package
-
-A role package must be configured with a package variable C<%__Meta> with the following keys (of which only "role"
-is mandatory):
- 
-=head3 role => 1 (Mandatory)
-
-This indicates that the package is a Role.
-
-=head3 has => HASHREF
-
-This works the same way as in an implementation package.
-
-=head3 semiprivate => ARRAYREF
-
-This works the same way as in an implementation package.
-
-=head3 requires => HASHREF
-
-A hash with keys:
-
-=head4 methods => ARRAYREF
-
-Any methods listed here must be provided by an implementation package or a role.
-
-=head4 attributes => ARRAYREF
-
-Any attributes listed here must be provided by an implementation package or a role, or by the "requires"
-definition in the class.
+    $object->DOES('Foo')
 
 =head1 BUGS
 
-Please report any bugs or feature requests via the GitHub web interface at 
-L<https://github.com/arunbear/perl5-minion/issues>.
+Please report any bugs or feature requests via the GitHub web interface at
+L<https://github.com/arunbear/minions/issues>.
 
 =head1 AUTHOR
 
