@@ -1,23 +1,21 @@
 package Example::Construction::Acme::Counter_v2;
 
-use strict;
-
-our %__Meta = (
+use Minions::Implementation
     has  => {
         count => { },
     }, 
-);
+;
 
 sub BUILD {
     my (undef, $self, $arg) = @_;
 
-    $self->{$$}{count} = $arg->{start};
+    $self->{$__count} = $arg->{start};
 }
 
 sub next {
     my ($self) = @_;
 
-    $self->{$$}{count}++;
+    $self->{$__count}++;
 }
 
 1;
