@@ -1,17 +1,15 @@
 package Example::Synopsis::Acme::Counter;
 
-use strict;
-
-our %__Meta = (
-    has  => {
+use Minions::Implementation
+    has => {
         count => { default => 0 },
-    }, 
-);
+    } 
+;
 
 sub next {
     my ($self) = @_;
 
-    $self->{$$}{count}++;
+    $self->{$__count}++;
 }
 
-1;
\ No newline at end of file
+1;
