@@ -1,21 +1,19 @@
 package Example::Usage::ArraySet;
 
-use strict;
-
-our %__Meta = (
+use Minions::Implementation
     has => { set => { default => sub { [] } } },
-);
+;
 
 sub has {
     my ($self, $e) = @_;
-    scalar grep { $_ == $e } @{ $self->{$$}{set} };
+    scalar grep { $_ == $e } @{ $self->{$__set} };
 }
 
 sub add {
     my ($self, $e) = @_;
 
     if ( ! $self->has($e) ) {
-        push @{ $self->{$$}{set} }, $e;
+        push @{ $self->{$__set} }, $e;
     }
 }
 
