@@ -1,19 +1,17 @@
 package Example::Usage::HashSet;
 
-use strict;
-
-our %__Meta = (
+use Minions::Implementation
     has => { set => { default => sub { {} } } },
-);
+;
 
 sub has {
     my ($self, $e) = @_;
-    exists $self->{$$}{set}{$e};
+    exists $self->{$__set}{$e};
 }
 
 sub add {
     my ($self, $e) = @_;
-    ++$self->{$$}{set}{$e};
+    ++$self->{$__set}{$e};
 }
 
 1;
