@@ -1,9 +1,6 @@
 package FixedSizeQueueRole;
 
-use strict;
-
-our %__Meta = (
-    role => 1,
+use Minions::Role
     has  => {
         q => { default => sub { [ ] } },
         max_size => { 
@@ -11,17 +8,17 @@ our %__Meta = (
             reader => 1,
         },
     }, 
-);
+;
 
 sub size {
     my ($self) = @_;
-    scalar @{ $self->{$$}{q} };
+    scalar @{ $self->{$__q} };
 }
 
 sub push {
     my ($self, $val) = @_;
 
-    push @{ $self->{$$}{q} }, $val;
+    push @{ $self->{$__q} }, $val;
 }
 
 1;
